function Aloc = STIMA_AIP(Vertices, ElemInfo, QuadRule, AHandle, varargin)

    nPoints = size(QuadRule.w,1);

    % Preallocate memory
    Aloc = zeros(3,3);

    % Compute element mapping
    bK = Vertices(1,:);
    BK = [Vertices(2,:)-bK; Vertices(3,:)-bK];
    inv_BK = inv(BK);
    det_BK = abs(det(BK));

    x = QuadRule.x*BK+ones(nPoints,1)*bK;

    % Compute element stiffness matrix
    grad_N = grad_shap_LFE(QuadRule.x);

    for i = 1:nPoints
        Aloc(1,1) = Aloc(1,1) + det_BK * QuadRule.w(i) * (grad_N(i,1:2) * (inv_BK'*AHandle(x(i,:))*inv_BK) * grad_N(i,1:2)');
        Aloc(1,2) = Aloc(1,2) + det_BK * QuadRule.w(i) * (grad_N(i,1:2) * (inv_BK'*AHandle(x(i,:))*inv_BK) * grad_N(i,3:4)');
        Aloc(1,3) = Aloc(1,3) + det_BK * QuadRule.w(i) * (grad_N(i,1:2) * (inv_BK'*AHandle(x(i,:))*inv_BK) * grad_N(i,5:6)');
        Aloc(2,2) = Aloc(2,2) + det_BK * QuadRule.w(i) * (grad_N(i,3:4) * (inv_BK'*AHandle(x(i,:))*inv_BK) * grad_N(i,3:4)');
        Aloc(2,3) = Aloc(2,3) + det_BK * QuadRule.w(i) * (grad_N(i,3:4) * (inv_BK'*AHandle(x(i,:))*inv_BK) * grad_N(i,5:6)');
        Aloc(3,3) = Aloc(3,3) + det_BK * QuadRule.w(i) * (grad_N(i,5:6) * (inv_BK'*AHandle(x(i,:))*inv_BK) * grad_N(i,5:6)');
    end

    % Update lower triangular part
    Aloc(2,1) = Aloc(1,2);
    Aloc(3,1) = Aloc(1,3);
    Aloc(3,2) = Aloc(2,3);

end
